﻿using Stimulsoft.Base.Drawing;
using Stimulsoft.Report.Components;
using System.Drawing;
using System.Drawing.Text;

namespace Merkur.Reports
{
    internal class Text : StiText
    {
        public Text(StiPage page, StiContainer parent, StiTextHorAlignment hor, StiVertAlignment vert, double x, double y, double width, double height, StiSystemTextType type, string fontFamily, float fontSize, Color fontColor, bool bold, bool italic, bool strikeout, bool underline, bool borderBottom, bool borderTop, bool borderLeft, bool borderRight, bool html)
        {
            SetPageParent(page, parent);
            SetRectangle(x, y, width, height);
            SetAlignment(hor, vert);
            SetTextType(type);
            SetBorder(FormatHelper.GetBorderSides(borderBottom, borderTop, borderLeft, borderRight), Color.Black, 1, StiPenStyle.Solid, false, 4, new StiSolidBrush(Color.Black), false);
            SetBrush(Color.Transparent);
            SetFont(fontFamily, fontSize, bold, italic, strikeout, underline, html);
            SetMargins(0, 0, 0, 0);
            SetTextBrush(fontColor);
            SetTextOptions();
        }

        private void SetPageParent(StiPage page, StiContainer parent)
        {
            Page = page;
            Parent = parent;
        }

        private void SetRectangle(double x, double y, double width, double height)
        {
            ClientRectangle = new RectangleD(x, y, width, height);
        }

        private void SetBorder(StiBorderSides sides, Color color, double thickness, StiPenStyle style, bool shadow, double shadowThickness, StiSolidBrush brush, bool topmost)
        {
            Border = new StiBorder(sides, color, thickness, style, shadow, shadowThickness, brush, topmost);
        }

        private void SetBrush(Color color)
        {
            Brush = new StiSolidBrush(color);
        }

        private void SetAlignment(StiTextHorAlignment horAlignment, StiVertAlignment vertAlignment)
        {
            HorAlignment = horAlignment;
            VertAlignment = vertAlignment;
        }

        private void SetTextType(StiSystemTextType type)
        {
            Type = type;
        }

        private void SetFont(string fontFamily, float fontSize, bool bold, bool italic, bool strikeout, bool underline, bool html)
        {
            AllowHtmlTags = html;
            Font = new Font(fontFamily, fontSize, FormatHelper.GetFontStyle(bold, italic, strikeout, underline));
        }

        private void SetMargins(double left, double right, double top, double bottom)
        {
            Margins = new StiMargins(left, right, top, bottom);
        }

        private void SetTextBrush(Color color)
        {
            TextBrush = new StiSolidBrush(color);
        }

        private void SetTextOptions()
        {
            TextOptions = new StiTextOptions(false, false, false, 0F, HotkeyPrefix.None, StringTrimming.None);
        }

        public StiText GetText()
        {
            return this;
        }
    }
}
