﻿using Stimulsoft.Base.Drawing;
using Stimulsoft.Report;
using Stimulsoft.Report.Components;
using Stimulsoft.Report.Dictionary;
using Stimulsoft.Report.Events;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Merkur.Reports
{
    public class DebtEnforcementWithPartitialClaimReport : StiReport
    {
        private readonly string mDataSourceName = "IncidentsByDebtEnforcementWithPartitialClaims";

        private DateTime mStart;
        private DateTime mEnd;
        private IncidentsByDebtEnforcementWithPartitialClaimsDataSource mIncidentsByDebtEnforcementWithPartitialClaims;

        private StiText mHeaderText;
        private StiText mFooterText;
        private StiText mIncidentNumberText;
        private StiText mStateText;
        private StiText mT1;
        private StiText mT2;
        private StiText mT3;
        private StiText mT4;

        public DebtEnforcementWithPartitialClaimReport(DateTime from, DateTime to)
        {
            SetVars(from, to);
            Pages.Clear();

            NeedsCompiling = false;
            EngineVersion = Stimulsoft.Report.Engine.StiEngineVersion.EngineV2;
            PreviewSettings = 268435455;
            ReferencedAssemblies = new string[] {
                    "System.Dll",
                    "System.Drawing.Dll",
                    "System.Windows.Forms.Dll",
                    "System.Data.Dll",
                    "System.Xml.Dll",
                    "Stimulsoft.Controls.Dll",
                    "Stimulsoft.Base.Dll",
                    "Stimulsoft.Report.Dll"};
            ReportAlias = "Vorgänge mit Teilforderung";
            ReportAuthor = "Christian Schneller";
            ReportDescription = "Der Bericht zeigt Vorgänge bei dennen beim Drucken des Antrag auf Vermögensauskunft nur eine Teilforderung vorhanden ist";
            ReportName = "Vorgänge mit Teilforderung";
            ReportUnit = Stimulsoft.Report.StiReportUnitType.Centimeters;
            ReportVersion = "2016.3.0";
            ScriptLanguage = Stimulsoft.Report.StiReportLanguageType.CSharp;

            StiPage page1 = new EmptyHorizontalPage(this);
            GetPageComponents(page1);

            Pages.Add(page1);

            mIncidentsByDebtEnforcementWithPartitialClaims.Columns.AddRange(new StiDataColumn[] {
                                                                                                    new StiDataColumn("Vorgangsnummer", "Vorgangsnummer", "Vorgangsnummer", typeof(string), null),
                                                                                                    new StiDataColumn("StatusID", "StatusID", "StatusID", typeof(int), null)
                                                                                                });

            DataSources.Add(mIncidentsByDebtEnforcementWithPartitialClaims);
            Dictionary.Databases.Add(new StiSqlDatabase("Merkur", "Merkur", "#%#", false, null));
            ((StiSqlDatabase)Dictionary.Databases["Merkur"]).ConnectionStringEncrypted = "5WyVAsVKQ91vS6FsYlzpj8NqYy1GVNn88ghN7OpJLA/WcMHCYV+SzeF42exjmGmfw3DN6+ZbQlFrWv2l5Rj2e8PEzwtFaKONaU+9mMMAIj/VyPcJZxjzbWFJ+YBjLGMv1VbR48UF+t3CUfkEagRlF8LEZSvIcHNlcBWklOmEsQ==";
            mIncidentsByDebtEnforcementWithPartitialClaims.Connecting += new EventHandler(GetSqlCommand);
            EndRender += new EventHandler(PageEndRender);
        }

        private void SetVars(DateTime from, DateTime to)
        {
            mStart = from;
            mEnd = to;
            mIncidentsByDebtEnforcementWithPartitialClaims = new IncidentsByDebtEnforcementWithPartitialClaimsDataSource();
        }

        private void GetPageComponents(StiPage page)
        {
            page.Components.AddRange(new StiComponent[] {
                                                            GetHeaderBand(page),
                                                            GetDataBand(page),
                                                            GetFooterBand(page)
                                                        });
        }

        private StiPageHeaderBand GetHeaderBand(StiPage page)
        {
            StiPageHeaderBand headerBand = new PageHeaderBand(page, 0, 0.4, 18.5, 1.2).GetBand();

            mHeaderText = new Text(page, headerBand, StiTextHorAlignment.Center, StiVertAlignment.Center, 0, 0, 18.5, 0.8, StiSystemTextType.Expression, "HelveticaNeue LT 55 Roman", 18, Color.Black, true, false, false, false, false, false, false, false, false);
            mHeaderText.GetValue += new StiGetValueEventHandler(GetHeaderText);

            headerBand.Components.AddRange(new StiComponent[] { mHeaderText });

            return headerBand;
        }

        private StiDataBand GetDataBand(StiPage page)
        {
            StiDataBand data = new DataBand(page, 0, 2.4, 18.5, 1.1, mDataSourceName, new string[0], true, false, false, false);

            mIncidentNumberText = new Text(page, data, StiTextHorAlignment.Left, StiVertAlignment.Center, 0, 0, 9.1, 1.1, StiSystemTextType.DataColumn, "HelveticaNeue LT 55 Roman", 16, Color.Black, false, false, false, false, false, false, false, true, false);
            mIncidentNumberText.GetValue += new StiGetValueEventHandler(GetIncidentNumberText);

            mStateText = new Text(page, data, StiTextHorAlignment.Center, StiVertAlignment.Center, 9.1, 0, 1.4, 1.1, StiSystemTextType.DataColumn, "HelveticaNeue LT 55 Roman", 16, Color.Black, false, false, false, false, false, false, false, true, false);
            mStateText.GetValue += new StiGetValueEventHandler(GetStateText);

            mT1 = new Text(page, data, StiTextHorAlignment.Center, StiVertAlignment.Center, 10.5, 0, 2, 1.1, StiSystemTextType.DataColumn, "HelveticaNeue LT 55 Roman", 16, Color.Black, false, false, false, false, false, false, false, true, false);
            mT2 = new Text(page, data, StiTextHorAlignment.Center, StiVertAlignment.Center, 12.5, 0, 2, 1.1, StiSystemTextType.DataColumn, "HelveticaNeue LT 55 Roman", 16, Color.Black, false, false, false, false, false, false, false, true, false);
            mT3 = new Text(page, data, StiTextHorAlignment.Center, StiVertAlignment.Center, 14.5, 0, 2, 1.1, StiSystemTextType.DataColumn, "HelveticaNeue LT 55 Roman", 16, Color.Black, false, false, false, false, false, false, false, true, false);
            mT4 = new Text(page, data, StiTextHorAlignment.Center, StiVertAlignment.Center, 16.5, 0, 2, 1.1, StiSystemTextType.DataColumn, "HelveticaNeue LT 55 Roman", 16, Color.Black, false, false, false, false, false, false, false, true, false);

            data.Components.AddRange(new StiComponent[] {
                                                            mIncidentNumberText,
                                                            mStateText,
                                                            mT1,
                                                            mT2,
                                                            mT3,
                                                            mT4
                                                        });

            return data;
        }

        private StiPageFooterBand GetFooterBand(StiPage page)
        {
            StiPageFooterBand footerBand = new PageFooterBand(page, 0, 28, 18.5, 0.7);

            mFooterText = new Text(page, footerBand, StiTextHorAlignment.Right, StiVertAlignment.Center, 0, 0.3, 20, 0.4, StiSystemTextType.Expression, "HelveticaNeue LT 55 Roman", 8, Color.Black, true, false, false, false, false, false, false, false, false);
            mFooterText.GetValue += new StiGetValueEventHandler(GetFooterText);

            footerBand.Components.AddRange(new StiComponent[] { mFooterText });

            return footerBand;
        }

        private void GetHeaderText(object sender, StiGetValueEventArgs e)
        {
            e.Value = string.Format("Vorgänge mit Teilforderung vom {0} bis {1}", mStart.ToShortDateString(), mEnd.ToShortDateString());
        }
        private void GetFooterText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "#%#{PageNofM}";
            e.StoreToPrinted = true;
        }
        private string GetFooterTextEnd(StiComponent sender)
        {
            return ToString(sender, PageNofM, true);
        }
        private void GetIncidentNumberText(object sender, StiGetValueEventArgs e)
        {
            e.Value = ToString(sender, mIncidentsByDebtEnforcementWithPartitialClaims.Vorgangsnummer, true);
        }
        private void GetStateText(object sender, StiGetValueEventArgs e)
        {
            e.Value = ToString(sender, mIncidentsByDebtEnforcementWithPartitialClaims.StatusID, true);
        }
        public void GetSqlCommand(object sender, System.EventArgs e)
        {
            mIncidentsByDebtEnforcementWithPartitialClaims.SqlCommand = "DECLARE @start datetime = CONVERT(DateTime, \'" + ToString(mStart) + "\', 104)\r\nDECLARE @end datetime = CONVERT(DateTime, \'" + ToString(mEnd) + "\', 104)\r\n\r\nSELECT\r\n\tCAST(v.Nummer as nvarchar)\r\n\t\t+ \'.\' + m.Nummer Vorgangsnummer,\r\n\t(SELECT TOP 1 StatusID FROM Statushistorie sh WHERE sh.SchuldnerProVorgangID = spv.ID ORDER BY StatusGesetztDatum desc) StatusID\r\nFROM Kosten k\r\nINNER JOIN Vorgang v\r\n\tON v.ID = k.VorgangID\r\nINNER JOIN Mandant m\r\n\tON m.ID = v.MandantID\r\nLEFT JOIN IncidentIsScanned i\r\n\tON i.IncidentId = v.ID\r\nINNER JOIN SchuldnerProVorgang spv\r\n\tON spv.VorgangID = v.ID\r\nWHERE\r\n\tk.KostenartID = 24\r\n\tAND k.Datum BETWEEN @start AND @end \r\n\tAND (SELECT SUM(k2.Endbetrag) FROM Kosten k2 WHERE k2.VorgangID = k.VorgangID AND k2.Datum < k.Datum)\r\n\t\t- (SELECT ISNULL(SUM(ISNULL(e.Betrag,0)), 0) FROM Einzahlung e WHERE e.VorgangID = k.VorgangID AND e.Datum < k.Datum) >= 150\r\n\tAND i.Id IS NULL\r\n\tAND (SELECT TOP 1 StatusID FROM Statushistorie sh WHERE sh.SchuldnerProVorgangID = spv.ID ORDER BY StatusGesetztDatum desc) NOT IN (25,63)\r\nORDER BY\r\n\tm.Nummer\r\n\t,v.Nummer";
        }

        private void PageEndRender(object sender, EventArgs e)
        {
            mFooterText.SetText(new StiGetValue(GetFooterTextEnd));
        }

        public StiReport GetStiReport()
        {
            return this;
        }
    }

    public class IncidentsByDebtEnforcementWithPartitialClaimsDataSource : StiSqlSource
    {

        public IncidentsByDebtEnforcementWithPartitialClaimsDataSource() :
            base("Merkur", "IncidentsByDebtEnforcementWithPartitialClaims", "IncidentsByDebtEnforcementWithPartitialClaims", "", true, false, 30, null)
        {
        }

        public virtual string Vorgangsnummer
        {
            get
            {
                return ((string)(StiReport.ChangeType(this["Vorgangsnummer"], typeof(string), true)));
            }
        }

        public virtual int StatusID
        {
            get
            {
                return ((int)(StiReport.ChangeType(this["StatusID"], typeof(int), true)));
            }
        }
    }
}
