﻿using Stimulsoft.Base.Drawing;
using Stimulsoft.Report.Components;
using Stimulsoft.Report.Events;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Merkur.Reports
{
    internal class HeaderModule : MDOWIModuleInterface
    {
        private MDOWIHeaderDto mHeader;
        private StiPage mPage;

        private StiHorizontalLinePrimitive ContactDataHorLine1;
        private StiHorizontalLinePrimitive ContactDataHorLine2;
        private StiHorizontalLinePrimitive ContactDataHorLine3;
        private StiHorizontalLinePrimitive ContactDataHorLine4;

        private StiRectanglePrimitive ContactDataRectangle;

        private StiText AgencyText;
        private StiText ContactDataElectronicalComunicationText;
        private StiText ContactDataElectronicalComunicationValueText;
        private StiText ContactDataFaxClientNumberText;
        private StiText ContactDataFaxClientNumberValueText;
        private StiText ContactDataHeaderText;
        private StiText ContactDataMailAccountText;
        private StiText ContactDataMailAccountValueText;
        private StiText ContactDataPhoneNumberText;
        private StiText ContactDataPhoneNumberValueText;
        private StiText ContactDataReferenceNumberText;
        private StiText ContactDataReferenceNumberValueText;
        private StiText CreditorAllowsSepaText;
        private StiText CreditorText;
        private StiText CreditorRepresantativeText;
        private StiText DistrictCourtText;
        private StiText IsAgencyText;
        private StiText IsCreditorAllowsSepaText;
        private StiText IsCreditorText;
        private StiText IsCreditorRepresantativeText;
        private StiText IsDistricCourtText;
        private StiText IsMarshalDistribution;
        private StiText IsMarshalText;
        private StiText MarshalDistributionText;
        private StiText MarshalNameValueText;
        private StiText MarshalText;
        private StiText ModuleText;
        private StiText PostalCodeCityText;
        private StiText PostalCodeCityValueText;
        private StiText StreetNumberText;
        private StiText StreetNumberValueText;
        private StiText SubTitleText;
        private StiText TitleText;
        private StiText Title2Text;

        private StiVerticalLinePrimitive ContactDataVertLine1;

        private StiStartPointPrimitive RecStart1;
        private StiStartPointPrimitive VerStart1;

        private StiEndPointPrimitive RecEnd1;
        private StiEndPointPrimitive VerEnd1;

        public HeaderModule(StiPage page, MDOWIHeaderDto header)
        {
            mPage = page;
            mHeader = header;

            InitializeComponents();
        }

        public StiComponent[] GetComponents()
        {
            return new StiComponent[]
                                {
                                    AgencyText,
                                    ContactDataElectronicalComunicationText,
                                    ContactDataElectronicalComunicationValueText,
                                    ContactDataFaxClientNumberText,
                                    ContactDataFaxClientNumberValueText,
                                    ContactDataHeaderText,
                                    ContactDataHorLine1,
                                    ContactDataHorLine2,
                                    ContactDataHorLine3,
                                    ContactDataHorLine4,
                                    ContactDataMailAccountText,
                                    ContactDataMailAccountValueText,
                                    ContactDataPhoneNumberText,ContactDataPhoneNumberValueText,
                                    ContactDataRectangle,
                                    ContactDataReferenceNumberText,
                                    ContactDataReferenceNumberValueText,
                                    ContactDataVertLine1,
                                    CreditorAllowsSepaText,
                                    CreditorRepresantativeText,
                                    CreditorText,
                                    DistrictCourtText,
                                    IsAgencyText,
                                    IsCreditorAllowsSepaText,
                                    IsCreditorRepresantativeText,
                                    IsCreditorText,
                                    IsDistricCourtText,
                                    IsMarshalDistribution,
                                    IsMarshalText,
                                    MarshalDistributionText,
                                    MarshalNameValueText,
                                    MarshalText,
                                    ModuleText,
                                    PostalCodeCityText,
                                    PostalCodeCityValueText,
                                    StreetNumberText,
                                    StreetNumberValueText,
                                    SubTitleText,
                                    TitleText,
                                    Title2Text,
                                };
        }

        public void InitializeComponents()
        {
            InitializeHorizontalLines();
            InitializeRectangles();
            InitializeTexts();
            InitializeVerticalLines();
        }

        public void InitializeHorizontalLines()
        {
            ContactDataHorLine1 = new HorizontalLine(mPage, mPage, 12.7, 5.55, 6.7, 0.0254);
            ContactDataHorLine2 = new HorizontalLine(mPage, mPage, 12.7, 6.6, 6.7, 0.0254);
            ContactDataHorLine3 = new HorizontalLine(mPage, mPage, 12.7, 7.55, 6.7, 0.0254);
            ContactDataHorLine4 = new HorizontalLine(mPage, mPage, 12.7, 9.5, 6.7, 0.0254);
        }

        public void InitializeRectangles()
        {
            ContactDataRectangle = new Rectangle(mPage, mPage, 12.7, 4.7, 6.7, 5.7);

            RecStart1 = new StiStartPointPrimitive();
            RecStart1.ClientRectangle = new RectangleD(12.7, 4.7, 0, 0);
            RecStart1.Page = mPage;
            RecStart1.Parent = mPage;

            RecEnd1 = new StiEndPointPrimitive();
            RecEnd1.ClientRectangle = new RectangleD(19.4, 10.4, 0, 0);
            RecEnd1.Page = mPage;
            RecEnd1.Parent = mPage;
        }

        public void InitializeTexts()
        {
            TitleText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 0, 2.05, 21, 0.55, StiSystemTextType.Expression, "Arial", 14, Color.Black, false, false, false, false, false, false, false, false, false);
            TitleText.GetValue += new StiGetValueEventHandler(GetTitleText);

            SubTitleText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 0, 2.45, 21, 0.4, StiSystemTextType.Expression, "Arial", 9, Color.Black, false, false, false, false, false, false, false, false, false);
            SubTitleText.GetValue += new StiGetValueEventHandler(GetSubTitleText);

            IsAgencyText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 2.4, 4.25, 0.4, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, true, true, true, false);
            IsAgencyText.GetValue += new StiGetValueEventHandler(GetIsAgencyText);

            AgencyText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Center, 3, 4.25, 7.5, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            AgencyText.GetValue += new StiGetValueEventHandler(GetAgencyText);

            IsMarshalDistribution = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 2.4, 3.75, 0.4, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, true, true, true, false);
            IsMarshalDistribution.GetValue += new StiGetValueEventHandler(GetIsMarshalDistribution);

            MarshalDistributionText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Center, 2.75, 3.75, 7.5, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            MarshalDistributionText.GetValue += new StiGetValueEventHandler(GetMarshalDistributionText);

            ContactDataElectronicalComunicationText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 12.75, 7.6, 3.4, 1.85, StiSystemTextType.Expression, "Arial", 9, Color.Black, false, false, false, false, false, false, false, false, true);
            ContactDataElectronicalComunicationText.GetValue += new StiGetValueEventHandler(GetContactDataElectronicalComunicationText);

            ContactDataElectronicalComunicationValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 16.25, 7.6, 3.2, 1.85, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataElectronicalComunicationValueText.GetValue += new StiGetValueEventHandler(GetContactDataElectronicalComunicationValueText);

            ContactDataFaxClientNumberText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 12.75, 5.6, 3.4, 0.9, StiSystemTextType.Expression, "Arial", 9, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataFaxClientNumberText.GetValue += new StiGetValueEventHandler(GetContactDataFaxClientNumberText);

            ContactDataFaxClientNumberValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 16.25, 5.6, 3.2, 0.9, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataFaxClientNumberValueText.GetValue += new StiGetValueEventHandler(GetContactDataFaxClientNumberValueText);

            ContactDataHeaderText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 12.7, 3.2, 3.3, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataHeaderText.GetValue += new StiGetValueEventHandler(GetContactDataHeaderText);

            ContactDataMailAccountText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 12.75, 6.65, 3.4, 0.9, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataMailAccountText.GetValue += new StiGetValueEventHandler(GetContactDataMailAccountText);

            ContactDataMailAccountValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 16.25, 6.65, 3.2, 0.9, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataMailAccountValueText.GetValue += new StiGetValueEventHandler(GetContactDataMailAccountValueText);

            ContactDataPhoneNumberText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 12.75, 4.75, 3.4, 0.9, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataPhoneNumberText.GetValue += new StiGetValueEventHandler(GetContactDataPhoneNumberText);

            ContactDataPhoneNumberValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 16.25, 4.75, 3.2, 0.9, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataPhoneNumberValueText.GetValue += new StiGetValueEventHandler(GetContactDataPhoneNumberValueText);

            ContactDataReferenceNumberText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 12.75, 9.55, 3.4, 0.9, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataReferenceNumberText.GetValue += new StiGetValueEventHandler(GetContactDataReferenceNumberText);

            ContactDataReferenceNumberValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 16.25, 9.55, 3.1, 0.9, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ContactDataReferenceNumberValueText.GetValue += new StiGetValueEventHandler(GetContactDataReferenceNumberValueText);

            CreditorAllowsSepaText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 13.3, 10.7, 6.2, 1.2, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            CreditorAllowsSepaText.GetValue += new StiGetValueEventHandler(GetCreditorAllowsSepaText);

            CreditorText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 13.3, 3.6, 3.3, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            CreditorText.GetValue += new StiGetValueEventHandler(GetCreditorText);

            CreditorRepresantativeText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 13.3, 4.1, 3.3, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            CreditorRepresantativeText.GetValue += new StiGetValueEventHandler(GetCreditorRepresantativeText);

            DistrictCourtText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 3, 3.25, 7.5, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            DistrictCourtText.GetValue += new StiGetValueEventHandler(GetDistrictCourtText);

            IsCreditorAllowsSepaText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 12.7, 10.7, 0.4, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, true, true, true, false);
            IsCreditorAllowsSepaText.GetValue += new StiGetValueEventHandler(GetIsCreditorAllowsSepaText);

            IsCreditorText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 12.7, 3.6, 0.4, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, true, true, true, false);
            IsCreditorText.GetValue += new StiGetValueEventHandler(GetIsCreditorText);

            IsCreditorRepresantativeText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 12.7, 4.1, 0.4, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, true, true, true, false);
            IsCreditorRepresantativeText.GetValue += new StiGetValueEventHandler(GetIsCreditorRepresantativeText);

            IsDistricCourtText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 2.4, 3.25, 0.4, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, true, true, true, false);
            IsDistricCourtText.GetValue += new StiGetValueEventHandler(GetIsDistricCourtText);

            IsMarshalText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Center, 2.4, 4.75, 0.4, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, true, true, true, false);
            IsMarshalText.GetValue += new StiGetValueEventHandler(GetIsMarshalText);

            MarshalDistributionText = new Text(mPage, mPage, StiTextHorAlignment.Center, StiVertAlignment.Top, 3, 3.75, 7.5, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            MarshalDistributionText.GetValue += new StiGetValueEventHandler(GetMarshalDistributionText);

            MarshalNameValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 2.4, 5.2, 8.1, 0.7, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, false, false, false, false);
            MarshalNameValueText.GetValue += new StiGetValueEventHandler(GetMarshalNameValueText);

            MarshalText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 3, 4.75, 7.5, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            MarshalText.GetValue += new StiGetValueEventHandler(GetMarshalText);

            ModuleText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 1.1, 15.4, 1.5, 0.4, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, false, false, false, false, false);
            ModuleText.GetValue += new StiGetValueEventHandler(GetModuleText);

            PostalCodeCityText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 2.4, 8.1, 8.1, 0.4, StiSystemTextType.Expression, "Arial", 7, Color.Black, false, false, false, false, false, false, false, false, false);
            PostalCodeCityText.GetValue += new StiGetValueEventHandler(GetPostalCodeCityText);

            PostalCodeCityValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 2.4, 7.4, 8.1, 0.7, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, false, false, false, false);
            PostalCodeCityValueText.GetValue += new StiGetValueEventHandler(GetPostalCodeCityValueText);

            StreetNumberText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 2.4, 7, 8.1, 0.4, StiSystemTextType.Expression, "Arial", 7, Color.Black, false, false, false, false, false, false, false, false, false);
            StreetNumberText.GetValue += new StiGetValueEventHandler(GetStreetNumberText);

            StreetNumberValueText = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 2.4, 6.3, 8.1, 0.7, StiSystemTextType.Expression, "Arial", 10, Color.Black, false, false, false, false, true, false, false, false, false);
            StreetNumberValueText.GetValue += new StiGetValueEventHandler(GetStreetNumberValueText);

            Title2Text = new Text(mPage, mPage, StiTextHorAlignment.Left, StiVertAlignment.Top, 2.2, 14.6, 7, 0.55, StiSystemTextType.Expression, "Arial", 11, Color.Black, false, false, false, false, false, false, false, false, false);
            Title2Text.GetValue += new StiGetValueEventHandler(GetTitle2Text);
        }

        public void InitializeVerticalLines()
        {
            ContactDataVertLine1 = new VerticalLine(mPage, mPage, 16.2, 4.7, 0.254, 5.7, "ContactDataVertLine1");

            VerStart1 = new StiStartPointPrimitive();
            VerStart1.ClientRectangle = new RectangleD(16.2, 4.7, 0, 0);
            VerStart1.Page = mPage;
            VerStart1.Parent = mPage;

            VerEnd1 = new StiEndPointPrimitive();
            VerEnd1.ClientRectangle = new RectangleD(16.2, 10.4, 0, 0);
            VerEnd1.Page = mPage;
            VerEnd1.Parent = mPage;
        }

        private void GetTitleText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Vollstreckungsauftrag an die Gerichtsvollzieherin/den Gerichtsvollzieher";
        }
        private void GetSubTitleText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "– zur Vollstreckung von Geldforderungen –";
        }
        private void GetDistrictCourtText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Amstgericht";
        }
        private void GetMarshalDistributionText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Verteilungsstelle für Gerichtsvollzieheraufträge";
        }
        private void GetAgencyText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Geschäftsstelle";
        }
        private void GetMarshalText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Frau/Herr Haupt-/Ober-/Gerichtsvollzieher/-in";
        }
        private void GetStreetNumberText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Straße, Hausnummer";
        }
        private void GetPostalCodeCityText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Postleitzahl, Ort";
        }
        private void GetContactDataHeaderText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Kontaktdaten des";
        }
        private void GetCreditorText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Gläubigers";
        }
        private void GetCreditorRepresantativeText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "GläubigerVertreters";
        }
        private void GetContactDataPhoneNumberText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Telefon";
        }
        private void GetContactDataFaxClientNumberText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Fax";
        }
        private void GetContactDataMailAccountText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "E-Mail";
        }
        private void GetContactDataElectronicalComunicationText(object sender, StiGetValueEventArgs e)
        {
            e.Value = string.Format("{0:}", "Rechtsverbindliche<br>elektronische<br>Kommunokationswege<br><font-size=\"6\">(z.B. De-Mail, EGVP,<br>besonderes Anwaltspostfach)</font-size>");
        }
        private void GetContactDataReferenceNumberText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Geschäftszeichen";
        }
        private void GetCreditorAllowsSepaText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Der Gläubiger beabsichtigt, für die Gerichts-\r\nvollzieherkosten ein SEPA-Lastschriftmandat\r\nzu erteilen.";
        }
        private void GetTitle2Text(object sender, StiGetValueEventArgs e)
        {
            e.Value = "In der Zwangsvollstreckungssache";
        }
        private void GetModuleText(object sender, StiGetValueEventArgs e)
        {
            e.Value = "Module:";
        }

        private void GetIsDistricCourtText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.IsDistrictCourt ? "X" : string.Empty;
        }
        private void GetIsMarshalDistribution(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.IsMarshalDistribution ? "X" : string.Empty;
        }
        private void GetIsAgencyText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.IsAgency ? "X" : string.Empty;
        }
        private void GetIsMarshalText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.IsMarshal ? "X" : string.Empty;
        }
        private void GetMarshalNameValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.Name;
        }
        private void GetStreetNumberValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.StreetNumber;
        }
        private void GetPostalCodeCityValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.PostalCodeNumber;
        }
        private void GetIsCreditorText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.IsCreditor ? "X" : string.Empty;
        }
        private void GetIsCreditorRepresantativeText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.IsCreditorRepresantative ? "X" : string.Empty;
        }
        private void GetContactDataPhoneNumberValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.PhoneNumber;
        }
        private void GetContactDataFaxClientNumberValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.FaxNumber;
        }
        private void GetContactDataMailAccountValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.MailAddress;
        }
        private void GetContactDataElectronicalComunicationValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.ElectronicalCommunication;
        }
        private void GetContactDataReferenceNumberValueText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.ReferenceNumber;
        }
        private void GetIsCreditorAllowsSepaText(object sender, StiGetValueEventArgs e)
        {
            e.Value = mHeader.CreditorAllowsSepa ? "X" : string.Empty;
        }
    }
}
